'use strict';

require('regenerator-runtime/runtime');
require('source-map-support').install();
var Once = require('./utils/Once');
var _ = require('lodash');
var bugsnag = require('bugsnag');
var uuidv1 = require('uuid/v1');
var Config = require('./Config');

module.exports = {
  initialize: function initialize() {
    var _this = this;

    if (!this.once) {
      this.once = new Once(function _callee() {
        var options, _iteratorNormalCompletion, _didIteratorError, _iteratorError, _iterator, _step, x;

        return regeneratorRuntime.async(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                // Set up configuration dict
                _this.config = new Config([require('./DataSources/Environment'), require('./DataSources/Credstash'), require('./DataSources/Clients'), require('./DataSources/Logging'), require('./DataSources/Replacer')]);

                // Needed until we are only async/await
                _context.next = 3;
                return regeneratorRuntime.awrap(_this.config.legacy().initialize());

              case 3:
                _context.next = 5;
                return regeneratorRuntime.awrap(_this.config.get('stage'));

              case 5:
                _context.t0 = _context.sent;
                _context.t1 = {
                  revision: process.env.BB_COMMIT,
                  errorId: uuidv1()
                };
                _context.t2 = ['cvv', 'lastName', 'address1', 'address2', 'address3', 'address4', 'email', 'token', 'city', 'state', 'province', 'zip', 'phone', 'birth_month', 'birth_day', 'birth_year', 'signature', 'accountNumber', 'routingNumber', 'ssn'];
                options = {
                  releaseStage: _context.t0,
                  sendCode: true,
                  metaData: _context.t1,
                  filters: _context.t2
                };
                _iteratorNormalCompletion = true;
                _didIteratorError = false;
                _iteratorError = undefined;
                _context.prev = 12;

                for (_iterator = process.listeners('uncaughtException')[Symbol.iterator](); !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
                  x = _step.value;

                  process.removeListener('uncaughtException', x);
                }
                _context.next = 20;
                break;

              case 16:
                _context.prev = 16;
                _context.t3 = _context['catch'](12);
                _didIteratorError = true;
                _iteratorError = _context.t3;

              case 20:
                _context.prev = 20;
                _context.prev = 21;

                if (!_iteratorNormalCompletion && _iterator.return) {
                  _iterator.return();
                }

              case 23:
                _context.prev = 23;

                if (!_didIteratorError) {
                  _context.next = 26;
                  break;
                }

                throw _iteratorError;

              case 26:
                return _context.finish(23);

              case 27:
                return _context.finish(20);

              case 28:
                _context.t4 = bugsnag;
                _context.next = 31;
                return regeneratorRuntime.awrap(_this.config.get('BUGSNAG_LAMBDAS_KEY'));

              case 31:
                _context.t5 = _context.sent;
                _context.t6 = options;

                _context.t4.register.call(_context.t4, _context.t5, _context.t6);

                process.on('uncaughtException', function (err) {
                  bugsnag.notify(err);
                });
                process.on('unhandledRejection', function (reason, p) {
                  bugsnag.notify(reason);
                });

              case 36:
              case 'end':
                return _context.stop();
            }
          }
        }, null, _this, [[12, 16, 20, 28], [21,, 23, 27]]);
      });
    }
    return this.once.do();
  },

  async: function async() {
    var _this2 = this;

    return {
      get: function get(key) {
        var value;
        return regeneratorRuntime.async(function get$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                _context2.next = 2;
                return regeneratorRuntime.awrap(_this2.initialize());

              case 2:
                value = _.get(_this2, key, null);

                if (!value) {
                  _context2.next = 5;
                  break;
                }

                return _context2.abrupt('return', value);

              case 5:
                _context2.next = 7;
                return regeneratorRuntime.awrap(_this2.config.get(key));

              case 7:
                return _context2.abrupt('return', _context2.sent);

              case 8:
              case 'end':
                return _context2.stop();
            }
          }
        }, null, _this2);
      },
      submodule: function submodule(name) {
        return _this2.submodule(name);
      }
    };
  },

  legacy: function legacy() {
    var _this3 = this;

    return {
      load: function load(next) {
        _this3.initialize().then(function () {
          _.defer(next);
        }).catch(function (error) {
          _.defer(next, error);
        });
      },
      get: function get(key) {
        if (!_this3.once || !_this3.once.done) {
          throw Error('Must call Common.legacy().load() before calling Common.legacy().get() (or Common.get())');
        }

        var value = _.get(_this3, key, null);
        if (value) {
          return value;
        }
        return _this3.config.legacy().get(key);
      },
      submodule: function submodule(name) {
        return _this3.submodule(name);
      }
    };
  },

  load: function load(next) {
    // Currently maps to legacy function
    this.legacy().load(next);
  },

  get: function get(key) {
    // Currently maps to legacy function
    return this.legacy().get(key);
  },

  submodule: function submodule(name) {
    return require('./' + name);
  }
};
//# sourceMappingURL=index.js.map